==> hadoop-client-api-3.2.4-sources.jar: org/apache/hadoop/yarn/api/protocolrecords/impl/pb/GetClusterMetricsResponsePBImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.protocolrecords.impl.pb;


import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Private;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability.Unstable;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.protocolrecords.GetClusterMetricsResponse;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.records.YarnClusterMetrics;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.records.impl.pb.YarnClusterMetricsPBImpl;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.proto.YarnProtos.YarnClusterMetricsProto;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.proto.YarnServiceProtos.GetClusterMetricsResponseProto;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.proto.YarnServiceProtos.GetClusterMetricsResponseProtoOrBuilder;

import org.apache.hadoop.shaded.com.google.protobuf.TextFormat;

@Private
@Unstable
public class GetClusterMetricsResponsePBImpl extends GetClusterMetricsResponse {
  GetClusterMetricsResponseProto proto = GetClusterMetricsResponseProto.getDefaultInstance();
  GetClusterMetricsResponseProto.Builder builder = null;
  boolean viaProto = false;
  
  private YarnClusterMetrics yarnClusterMetrics = null;
  
  
  public GetClusterMetricsResponsePBImpl() {
    builder = GetClusterMetricsResponseProto.newBuilder();
  }

  public GetClusterMetricsResponsePBImpl(GetClusterMetricsResponseProto proto) {
    this.proto = proto;
    viaProto = true;
  }
  
  public GetClusterMetricsResponseProto getProto() {
      mergeLocalToProto();
    proto = viaProto ? proto : builder.build();
    viaProto = true;
    return proto;
  }

  @Override
  public int hashCode() {
    return getProto().hashCode();
  }

  @Override
  public boolean equals(Object other) {
    if (other == null)
      return false;
    if (other.getClass().isAssignableFrom(this.getClass())) {
      return this.getProto().equals(this.getClass().cast(other).getProto());
    }
    return false;
  }

  @Override
  public String toString() {
    return TextFormat.shortDebugString(getProto());
  }

  private void mergeLocalToBuilder() {
    if (this.yarnClusterMetrics != null) {
      builder.setClusterMetrics(convertToProtoFormat(this.yarnClusterMetrics));
    }
  }

  private void mergeLocalToProto() {
    if (viaProto) 
      maybeInitBuilder();
    mergeLocalToBuilder();
    proto = builder.build();
    viaProto = true;
  }

  private void maybeInitBuilder() {
    if (viaProto || builder == null) {
      builder = GetClusterMetricsResponseProto.newBuilder(proto);
    }
    viaProto = false;
  }
    
  
  @Override
  public YarnClusterMetrics getClusterMetrics() {
    GetClusterMetricsResponseProtoOrBuilder p = viaProto ? proto : builder;
    if (this.yarnClusterMetrics != null) {
      return this.yarnClusterMetrics;
    }
    if (!p.hasClusterMetrics()) {
      return null;
    }
    this.yarnClusterMetrics = convertFromProtoFormat(p.getClusterMetrics());
    return this.yarnClusterMetrics;
  }

  @Override
  public void setClusterMetrics(YarnClusterMetrics clusterMetrics) {
    maybeInitBuilder();
    if (clusterMetrics == null) 
      builder.clearClusterMetrics();
    this.yarnClusterMetrics = clusterMetrics;
  }

  private YarnClusterMetricsPBImpl convertFromProtoFormat(YarnClusterMetricsProto p) {
    return new YarnClusterMetricsPBImpl(p);
  }

  private YarnClusterMetricsProto convertToProtoFormat(YarnClusterMetrics t) {
    return ((YarnClusterMetricsPBImpl)t).getProto();
  }



}

==> hadoop-client-api-3.3.6-sources.jar: org/apache/hadoop/yarn/api/protocolrecords/impl/pb/GetClusterMetricsResponsePBImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.protocolrecords.impl.pb;


import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Private;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability.Unstable;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.protocolrecords.GetClusterMetricsResponse;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.records.YarnClusterMetrics;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.records.impl.pb.YarnClusterMetricsPBImpl;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.proto.YarnProtos.YarnClusterMetricsProto;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.proto.YarnServiceProtos.GetClusterMetricsResponseProto;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.proto.YarnServiceProtos.GetClusterMetricsResponseProtoOrBuilder;

import org.apache.hadoop.shaded.org.apache.hadoop.thirdparty.protobuf.TextFormat;

@Private
@Unstable
public class GetClusterMetricsResponsePBImpl extends GetClusterMetricsResponse {
  GetClusterMetricsResponseProto proto = GetClusterMetricsResponseProto.getDefaultInstance();
  GetClusterMetricsResponseProto.Builder builder = null;
  boolean viaProto = false;
  
  private YarnClusterMetrics yarnClusterMetrics = null;
  
  
  public GetClusterMetricsResponsePBImpl() {
    builder = GetClusterMetricsResponseProto.newBuilder();
  }

  public GetClusterMetricsResponsePBImpl(GetClusterMetricsResponseProto proto) {
    this.proto = proto;
    viaProto = true;
  }
  
  public GetClusterMetricsResponseProto getProto() {
      mergeLocalToProto();
    proto = viaProto ? proto : builder.build();
    viaProto = true;
    return proto;
  }

  @Override
  public int hashCode() {
    return getProto().hashCode();
  }

  @Override
  public boolean equals(Object other) {
    if (other == null)
      return false;
    if (other.getClass().isAssignableFrom(this.getClass())) {
      return this.getProto().equals(this.getClass().cast(other).getProto());
    }
    return false;
  }

  @Override
  public String toString() {
    return TextFormat.shortDebugString(getProto());
  }

  private void mergeLocalToBuilder() {
    if (this.yarnClusterMetrics != null) {
      builder.setClusterMetrics(convertToProtoFormat(this.yarnClusterMetrics));
    }
  }

  private void mergeLocalToProto() {
    if (viaProto) 
      maybeInitBuilder();
    mergeLocalToBuilder();
    proto = builder.build();
    viaProto = true;
  }

  private void maybeInitBuilder() {
    if (viaProto || builder == null) {
      builder = GetClusterMetricsResponseProto.newBuilder(proto);
    }
    viaProto = false;
  }
    
  
  @Override
  public YarnClusterMetrics getClusterMetrics() {
    GetClusterMetricsResponseProtoOrBuilder p = viaProto ? proto : builder;
    if (this.yarnClusterMetrics != null) {
      return this.yarnClusterMetrics;
    }
    if (!p.hasClusterMetrics()) {
      return null;
    }
    this.yarnClusterMetrics = convertFromProtoFormat(p.getClusterMetrics());
    return this.yarnClusterMetrics;
  }

  @Override
  public void setClusterMetrics(YarnClusterMetrics clusterMetrics) {
    maybeInitBuilder();
    if (clusterMetrics == null) 
      builder.clearClusterMetrics();
    this.yarnClusterMetrics = clusterMetrics;
  }

  private YarnClusterMetricsPBImpl convertFromProtoFormat(YarnClusterMetricsProto p) {
    return new YarnClusterMetricsPBImpl(p);
  }

  private YarnClusterMetricsProto convertToProtoFormat(YarnClusterMetrics t) {
    return ((YarnClusterMetricsPBImpl)t).getProto();
  }



}
